@@ -1,16 +1,22 @@
 #!/usr/bin/env python
 # encoding: utf-8
 
-from blueflask.flask_api import app
+from blueflask.flask_api import FlaskApp
 
 from .v2 import api
 from .v2 import __version__
-from ..consts import API_REGISTRY
-from ..consts import LOGS
+from ..consts import ADDRESS
+from ..consts import APIGW
 from ..consts import HOSTNAME
+from ..consts import LOGS
 from ..consts import SERVICE_CODE
 
+import requests
 
+flask_app = FlaskApp(SERVICE_CODE)
+flask_app.produce_handlers_and_documentation()
+
+app = flask_app.app
 app.config['LOGGER_NAME'] = 'ldap-services-api'
 app.config['TITLE'] = 'API LDAP'
 app.config['DESCRIPTION'] = "API pour l'annuaire LDAP de blueline"
@@ -18,14 +24,18 @@ app.config['VERSION'] = __version__
 app.logger.handlers = LOGS.logger.handlers
 app.register_blueprint(api)
 
-
-API_REGISTRY.hmset(
-    'service:ldap-services',
-    {
+requests.post(
+    'https://{fqdn}/registry'.format(fqdn=APIGW),
+    json={
+        'service': 'ldap',
+        'address': ADDRESS,
         'service_code': SERVICE_CODE,
         'host': HOSTNAME,
         'status': 'up'
         }
     )
 
+if __name__ == '__main__':
+    app.run(debug=True)
+
 # EOF
