@@ -33,6 +33,6 @@ def method_not_allowed_error(e):
     return not_allowed(service_code=SERVICE_CODE)
 
 
-from . import apps, auth, departments, positions, users, requests  # NOQA
+from . import apps, auth, departments, positions, users  # NOQA
 
 # EOF
