@@ -11,19 +11,18 @@ import configparser
 import socket
 
 import ldap
-import redis
 
 
 __all__ = [
+    'ADDRESS',
+    'APIGW',
     'CONFIG',
-    'LDAP_SERVER',
+    'HOSTNAME',
     'LDAP_ADMIN_DN',
     'LDAP_CONN',
+    'LDAP_SERVER',
     'LOGS',
-    'REDIS_SERVER',
-    'SERVICE_CODE',
-    'HOSTNAME',
-    'API_REGISTRY'
+    'SERVICE_CODE'
     ]
 
 
@@ -31,10 +30,18 @@ CONFIG = configparser.ConfigParser(allow_no_value=True)
 CONFIG.read('/etc/ldap-services/ldap-services.conf')
 
 SERVICE_CODE = CONFIG['APP']['service_code']
+GUNICORN_PORT = int(SERVICE_CODE[1:].replace('-', ''))
 HOSTNAME = socket.gethostname().split('.')[0]
-API_REGISTRY = redis.Redis(db=15)
-if HOSTNAME.startswith('blpr'):
-    API_REGISTRY = redis.Redis(host='api.blueline.mg', db=15)
+_socket = socket.socket(socket.AF_INET, socket.SOCK_DGRAM)
+_socket.connect(("41.204.103.205", 80))
+ADDRESS = _socket.getsockname()[0]
+
+if HOSTNAME.startswith('bldv'):
+    APIGW = 'bldv040v.blueline.mg'
+elif HOSTNAME.startswith('blst'):
+    APIGW = 'blst040v.blueline.mg'
+else:
+    APIGW = 'api.blueline.mg'
 
 LDAP_SERVER = CONFIG['LDAP']['LDAP_SERVER']
 LDAP_ADMIN_DN = CONFIG['LDAP']['LDAP_ADMIN_DN']
@@ -53,6 +60,4 @@ LOGS.set_file_handler(LOG_FILE, level=LOG_LEVEL)
 BLUEFLASK_LOGS = Logger('blueflask')
 BLUEFLASK_LOGS.set_file_handler(LOG_FILE, level=LOG_LEVEL)
 
-REDIS_SERVER = redis.Redis()
-
 # EOF
